@@ -1,4 +1,4 @@
-# Copyrights 2001-2024 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -7,7 +7,7 @@
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Body::Multipart;{
-our $VERSION = '3.016';
+our $VERSION = '3.017';
 }
 
 use base 'Mail::Message::Body';
@@ -57,8 +57,7 @@ sub init($)
 
         $self->{MMBM_parts}
             = @parts ? \@parts
-            : !$args->{parts} && $based->isMultipart
-                     ? [ $based->parts('ACTIVE') ]
+            : !$args->{parts} && $based->isMultipart ? [ $based->parts('ACTIVE') ]
             :          [];
 
         $self->{MMBM_epilogue}
